{% extends "allauth/account/base.html" %}

{% load i18n %}
{% block head_title %}{% trans "Change Password" %}{% endblock %}

{% block content %}
    <h2 class="title">{% trans "Change Password" %}</h2>
    <p>{% trans 'Your password is now changed.' %}</p>
{% endblock %}
