{% extends "allauth/account/base.html" %}

{% load i18n crispy_forms_tags %}

{% block head_title %}{% trans "Signup" %}{% endblock %}

{% block content %}
    <h2 class="title">{% trans "Sign up" %}</h2>

    <p>{% blocktrans %}Already have an account? Then please <strong><a class="link" href="{{ login_url }}">sign in</a></strong>.{% endblocktrans %}
    </p>

    <form class="signup mt-5" id="signup_form" method="post" action="{% url 'account_signup' %}">
        {% csrf_token %}
        {{ form|crispy }}
        {% if redirect_field_value %}
            <input type="hidden" name="{{ redirect_field_name }}" value="{{ redirect_field_value }}"/>
        {% endif %}
        <button class="primaryAction" type="submit">{% trans "Sign Up" %} &raquo;</button>
    </form>

{% endblock %}
