{% extends "allauth/account/base.html" %}

{% load i18n %}

{% block head_title %}{% trans "Sign Up Closed" %}{% endblock %}

{% block content %}
    <h2 class="title">{% trans "Sign Up Closed" %}</h2>

    <p>{% trans "We are sorry, but the sign up is currently closed." %}</p>
{% endblock %}
