{% extends "allauth/account/base.html" %}

{% load i18n crispy_forms_tags %}

{% block head_title %}{% trans "Change Password" %}{% endblock %}

{% block content %}
    <h2 class="title">{% trans "Change Password" %}</h2>

    <form method="POST" action="{% url 'account_change_password' %}" class="password_change">
        {% csrf_token %}
        {{ form|crispy }}
        <button class="primaryAction" type="submit" name="action">{% trans "Change Password" %}</button>
        <strong><a class="link ml-2" href="{% url 'account_reset_password' %}">{% trans "Forgot Password?" %}</a></strong>
    </form>
{% endblock %}
