{% extends "allauth/account/base.html" %}

{% load i18n crispy_forms_tags %}
{% block head_title %}{% trans "Change Password" %}{% endblock %}

{% block content %}
    <h2 class="title">{% if token_fail %}{% trans "Bad Token" %}{% else %}{% trans "Change Password" %}{% endif %}</h2>

    {% if token_fail %}
        {% url 'account_reset_password' as passwd_reset_url %}
        <p>{% blocktrans %}The password reset link was invalid, possibly because it has already been used.  Please request a <a class="link" href="{{ passwd_reset_url }}">new password reset</a>.{% endblocktrans %}</p>
    {% else %}
        <form method="POST" action="{{ action_url }}">
            {% csrf_token %}
            {{ form|crispy }}
            <button class="primaryAction" type="submit" name="action">{% trans 'change password' %}</button>
        </form>
    {% endif %}
{% endblock %}
