{% extends "allauth/account/base.html" %}

{% load i18n crispy_forms_tags %}

{% block head_title %}{% trans "Set Password" %}{% endblock %}

{% block content %}
    <h2 class="title">{% trans "Set Password" %}</h2>

    <form method="POST" action="{% url 'account_set_password' %}" class="password_set">
        {% csrf_token %}
        {{ form|crispy }}
        <input class="primaryAction" type="submit" name="action" value="{% trans 'Set Password' %}"/>
    </form>
{% endblock %}
