{% extends "allauth/account/base.html" %}

{% load i18n %}

{% block head_title %}{% trans "Verify Your E-mail Address" %}{% endblock %}

{% block content %}
    <h2 class="title">{% trans "Verify Your E-mail Address" %}</h2>

    <p>{% blocktrans %}We have sent an e-mail to you for verification. Follow the link provided to finalize the signup
        process. If you do not see the verification e-mail in your main inbox, check your spam folder. Please contact us
        if you do not receive the verification e-mail within a few minutes.{% endblocktrans %}</p>

{% endblock %}
